Roman Pišl : kernelbase: Fix comment and trace message in console.

Alexandre Julliard julliard at winehq.org
Mon Oct 19 15:54:04 CDT 2020


Module: wine
Branch: master
Commit: c8af17187ef48816cdf42ced5ade7ee5d8d2842a
URL:    https://source.winehq.org/git/wine.git/?a=commit;h=c8af17187ef48816cdf42ced5ade7ee5d8d2842a

Author: Roman Pišl <rpisl at seznam.cz>
Date:   Sun Oct 18 12:47:42 2020 +0200

kernelbase: Fix comment and trace message in console.

Signed-off-by: Roman Pišl <rpisl at seznam.cz>
Signed-off-by: Alexandre Julliard <julliard at winehq.org>

---

 dlls/kernelbase/console.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/dlls/kernelbase/console.c b/dlls/kernelbase/console.c
index d387b49c534..71c594b3c18 100644
--- a/dlls/kernelbase/console.c
+++ b/dlls/kernelbase/console.c
@@ -351,7 +351,7 @@ BOOL WINAPI AllocConsole(void)
 
     memset(&console_si, 0, sizeof(console_si));
     console_si.cb = sizeof(console_si);
     /* setup a view arguments for wineconsole (it'll use them as default values)  */
     if (app_si.dwFlags & STARTF_USECOUNTCHARS)
     {
         console_si.dwFlags |= STARTF_USECOUNTCHARS;
@@ -386,7 +386,7 @@ BOOL WINAPI AllocConsole(void)
     if (!init_console_std_handles( !(app_si.dwFlags & STARTF_USESTDHANDLES) )) goto error;
 
     RtlGetCurrentPeb()->ProcessParameters->ConsoleHandle = console;
-    TRACE( "Started wineconsole pid=%08x tid=%08x\n", pi.dwProcessId, pi.dwThreadId );
+    TRACE( "Started conhost pid=%08x tid=%08x\n", pi.dwProcessId, pi.dwThreadId );
 
     CloseHandle( server );
     RtlLeaveCriticalSection( &console_section );
@@ -351,7 +351,7 @@ BOOL WINAPI AllocConsole(void)
     memset(&console_si, 0, sizeof(console_si));
     console_si.cb = sizeof(console_si);
-    /* setup a view arguments for wineconsole (it'll use them as default values)  */
+    /* setup a view arguments for conhost (it'll use them as default values)  */
     if (app_si.dwFlags & STARTF_USECOUNTCHARS)
     {




More information about the wine-cvs mailing list